@@ -15,6 +15,7 @@ from opentelemetry.exporter.otlp.proto.http.trace_exporter import OTLPSpanExport
 
 from opentelemetry.sdk.trace import TracerProvider, SpanProcessor, Span
 from opentelemetry.sdk.trace.export import BatchSpanProcessor
+from opentelemetry.sdk.resources import Resource
 
 from opentelemetry.trace import (
     set_tracer_provider,
@@ -41,38 +42,7 @@ class QuotientAttributes(str, Enum):
     app_name = "app.name"
     environment = "app.environment"
     detections = "quotient.detections"
-
-
-class QuotientAttributesSpanProcessor(SpanProcessor):
-    """
-    Processor that adds Quotient-specific attributes to all spans, including:
-    
-    - `app_name`
-    - `environment`
-
-    Which are all required for tracing.
-    """
-
-    app_name: str
-    environment: str
-    detections: str
-
-    def __init__(self, app_name: str, environment: str, detections: Optional[str] = None):
-        self.app_name = app_name
-        self.environment = environment
-        self.detections = detections
-
-    def on_start(self, span: Span, parent_context: Optional[otel_context.Context] = None) -> None:
-        attributes = {
-            QuotientAttributes.app_name: self.app_name,
-            QuotientAttributes.environment: self.environment,
-        }
-
-        if self.detections is not None:
-            attributes[QuotientAttributes.detections] = self.detections
-
-        span.set_attributes(attributes)
-        super().on_start(span, parent_context)
+    user = "quotient.user"
 
 
 class TracingResource:
@@ -154,6 +124,17 @@ class TracingResource:
         """
         return OTLPSpanExporter(endpoint=endpoint, headers=headers)
 
+
+    def _get_user(self):
+        """
+        Get user_id from client.
+        Returns the user_id or None if not found.
+        """
+        if hasattr(self._client, '_user'):
+            return self._client._user
+        return "None"
+
+
     @functools.lru_cache()
     def _setup_auto_collector(self, app_name: str, environment: str, instruments: Optional[tuple] = None, detections: Optional[str] = None):
         """
@@ -165,14 +146,28 @@ class TracingResource:
 
             # Only set up if not already configured (avoid double setup)
             if not hasattr(current_provider, '_span_processors') or not current_provider._span_processors:
-                tracer_provider = TracerProvider()
+                
+                # Create resource with quotient attributes
+                resource_attributes = {
+                    QuotientAttributes.app_name: app_name,
+                    QuotientAttributes.environment: environment,
+                    QuotientAttributes.user: self._get_user(),
+                }
+                
+                if detections is not None:
+                    resource_attributes[QuotientAttributes.detections] = detections
+                
+                resource = Resource.create(resource_attributes)
+                
+                # Create TracerProvider with the resource
+                tracer_provider = TracerProvider(resource=resource)
                 
                 # Get collector endpoint from environment or use default
                 exporter_endpoint = os.environ.get(
                     "OTEL_EXPORTER_OTLP_ENDPOINT",
                     DEFAULT_TRACING_ENDPOINT,
                 )
-                
+
                 # Parse headers from environment or use default
                 headers = {
                     "Authorization": f"Bearer {self._client.api_key}",
@@ -191,12 +186,6 @@ class TracingResource:
 
                 # Use batch processor for better performance
                 span_processor = BatchSpanProcessor(otlp_exporter)
-                quotient_attributes_span_processor = QuotientAttributesSpanProcessor(
-                    app_name=app_name,
-                    environment=environment,
-                    detections=detections,
-                )
-                tracer_provider.add_span_processor(quotient_attributes_span_processor)
                 tracer_provider.add_span_processor(span_processor)
                 
                 # Set the global tracer provider
@@ -216,18 +205,25 @@ class TracingResource:
             # Fallback to no-op tracer
             self.tracer = None
 
-    def trace(self):
+    def trace(self, name: Optional[str] = None):
         """
         Decorator to trace function calls for Quotient.
         
         The TracingResource must be pre-configured via the configure() method
         before using this decorator.
         
+        Args:
+            name: Optional custom name for the span. If not provided, uses func.__qualname__
+        
         Example:
             quotient.tracer.init(app_name="my_app", environment="prod")
             @quotient.trace()
             def my_function():
                 pass
+            
+            @quotient.trace('myagent')
+            def my_other_function():
+                pass
         """
         # Use only configured values - no parameters accepted
         if not self._app_name or not self._environment:
@@ -235,7 +231,7 @@ class TracingResource:
             return lambda func: func
 
         def decorator(func):
-            name = func.__qualname__
+            span_name = name if name is not None else func.__qualname__
 
             @functools.wraps(func)
             def sync_func_wrapper(*args, **kwargs):
@@ -251,7 +247,7 @@ class TracingResource:
                 if self.tracer is None:
                     return func(*args, **kwargs)
 
-                with self.tracer.start_as_current_span(name) as root_span:
+                with self.tracer.start_as_current_span(span_name) as root_span:
                     try:
                         result = func(*args, **kwargs)
                     except Exception as e:
@@ -278,7 +274,7 @@ class TracingResource:
                 if self.tracer is None:
                     return await func(*args, **kwargs)
 
-                with self.tracer.start_as_current_span(name) as root_span:
+                with self.tracer.start_as_current_span(span_name) as root_span:
                     try:
                         result = await func(*args, **kwargs)
                     except Exception as e:
