@@ -282,12 +282,18 @@ class QdrantInstrumentor(BaseInstrumentor):
                     span.set_attribute("db.operation.status", "completed")
                     
                     # Add retrieved documents if available
+                    vector_data = None
                     if hasattr(result, 'result') and result.result:
-                        span.set_attribute("db.ids_count", len(result.result))
+                        vector_data = result.result
+                    elif isinstance(result, list):
+                        vector_data = result
+                    
+                    if vector_data:
+                        span.set_attribute("db.ids_count", len(vector_data))
                         
                         # Format documents for span attributes
                         documents = []
-                        for point in result.result:
+                        for point in vector_data:
                             doc = {"id": point.id, "score": point.score}
                             if hasattr(point, 'payload') and point.payload:
                                 doc["metadata"] = point.payload
@@ -405,12 +411,18 @@ class QdrantInstrumentor(BaseInstrumentor):
                     span.set_attribute("db.operation.status", "completed")
                     
                     # Add retrieved documents if available
+                    vector_data = None
                     if hasattr(result, 'result') and result.result:
-                        span.set_attribute("db.ids_count", len(result.result))
+                        vector_data = result.result
+                    elif isinstance(result, list):
+                        vector_data = result
+                    
+                    if vector_data:
+                        span.set_attribute("db.ids_count", len(vector_data))
                         
                         # Format documents for span attributes
                         documents = []
-                        for point in result.result:
+                        for point in vector_data:
                             doc = {"id": point.id}
                             if hasattr(point, 'payload') and point.payload:
                                 doc["metadata"] = point.payload
@@ -469,12 +481,18 @@ class QdrantInstrumentor(BaseInstrumentor):
                     span.set_attribute("db.operation.status", "completed")
                     
                     # Add retrieved documents if available
+                    vector_data = None
                     if hasattr(result, 'result') and result.result:
-                        span.set_attribute("db.vector_count", len(result.result))
+                        vector_data = result.result
+                    elif isinstance(result, list):
+                        vector_data = result
+                    
+                    if vector_data:
+                        span.set_attribute("db.vector_count", len(vector_data))
                         
                         # Format documents for span attributes
                         documents = []
-                        for point in result.result:
+                        for point in vector_data:
                             doc = {"id": point.id}
                             if hasattr(point, 'payload') and point.payload:
                                 doc["metadata"] = point.payload
@@ -519,4 +537,4 @@ class QdrantInstrumentor(BaseInstrumentor):
                 
                 self._original_methods.clear()
         except ImportError:
-            pass 
\ No newline at end of file
+            pass
